@@ -68,6 +68,7 @@ Frame_Glom::Frame_Glom(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade:
 : PlaceHolder(cobject, refGlade),
   m_pLabel_Name(0),
   m_pLabel_Table(0),
+  m_box_footer(0),
   m_pLabel_Mode(0),
   m_pLabel_userlevel(0),
   m_pBox_QuickFind(0),
@@ -81,21 +82,29 @@ Frame_Glom::Frame_Glom(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade:
   m_pBox_Tables(0),
   m_pDialog_Tables(0),
 #ifndef GLOM_ENABLE_CLIENT_ONLY
-  m_pBox_Reports(0),
   m_pDialog_Reports(0),
-  m_pDialogLayoutReport(0),
+  m_pBox_Reports(0),
   m_pDialog_Fields(0),
   m_pDialog_Relationships(0),
   m_dialog_addrelatedtable(0),
+  m_pDialogLayoutReport(0),
 #endif // !GLOM_ENABLE_CLIENT_ONLY
-  m_pDialogConnection(0),
-  m_pDialogConnectionFailed(0)
+  m_pDialogConnection(0)
 {
   //Load widgets from glade file:
   refGlade->get_widget("label_name", m_pLabel_Name);
   refGlade->get_widget("label_table_name", m_pLabel_Table);
+
+  refGlade->get_widget("hbox_footer", m_box_footer);
   refGlade->get_widget("label_mode", m_pLabel_Mode);
   refGlade->get_widget("label_user_level", m_pLabel_userlevel);
+  
+  //Hide the footer on maemo (It takes too much space),
+  //and reduce the border width:
+  #ifdef GLOM_ENABLE_MAEMO
+  m_box_footer->hide();
+  set_border_width(Glom::Utils::DEFAULT_SPACING_LARGE);
+  #endif
 
   refGlade->get_widget("hbox_quickfind", m_pBox_QuickFind);
   m_pBox_QuickFind->hide();
@@ -246,30 +255,6 @@ Frame_Glom::Frame_Glom(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade:
   }
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
-
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
-  try
-  {
-    refXml = Gnome::Glade::Xml::create(GLOM_GLADEDIR "glom.glade", "dialog_error_connection");
-
-  }
-  catch(const Gnome::Glade::XmlError& ex)
-  {
-    std::cerr << ex.what() << std::endl;
-  }
-#else
-  error.reset(NULL);
-  refXml = Gnome::Glade::Xml::create(GLOM_GLADEDIR "glom.glade", "dialog_error_connection", "", error);
-  if(error.get()) std::cerr << error->what() << std::endl;
-#endif
-
-  if(refXml)
-  {
-    refXml->get_widget("dialog_error_connection", m_pDialogConnectionFailed);
-    refXml.clear();
-  }
-
-
   m_Mode = MODE_None;
   m_Mode_Previous = MODE_None;
 
@@ -343,12 +328,6 @@ Frame_Glom::~Frame_Glom()
     m_pDialogConnection = 0;
   }
 
-  if(m_pDialogConnectionFailed)
-  {
-    delete m_pDialogConnectionFailed;
-    m_pDialogConnectionFailed = 0;
-  }
-
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   if(m_pDialog_Relationships)
   {
@@ -683,7 +662,7 @@ void Frame_Glom::on_menu_file_export()
   std::fstream the_stream(filepath.c_str(), std::ios_base::out | std::ios_base::trunc);
   if(!the_stream)
   {
-      show_ok_dialog(_("Could Not Create File."), _("Glom could not create the specified file."), *pWindowApp, Gtk::MESSAGE_ERROR);
+    show_ok_dialog(_("Could Not Create File."), _("Glom could not create the specified file."), *pWindowApp, Gtk::MESSAGE_ERROR);
     return;
   }
 
@@ -1169,7 +1148,7 @@ void Frame_Glom::show_table_title()
 #ifdef GLOM_ENABLE_MAEMO
     // xx-large is too large on maemo, taking away too much (vertical)
     // screen estate
-    m_pLabel_Table->set_markup("<b><span size=\"large\">" + table_label + "</span></b>");
+    m_pLabel_Table->set_markup("<b>" + table_label + "</b>");
 #else
     m_pLabel_Table->set_markup("<b><span size=\"xx-large\">" + table_label + "</span></b>"); //Show the table title in large text, because it's very important to the user.
 #endif
@@ -1682,13 +1661,7 @@ bool Frame_Glom::connection_request_password_and_choose_new_database_name()
         if(ex.get_failure_type() == ExceptionConnection::FAILURE_NO_SERVER)
         {
           //Warn the user, and let him try again:
-          m_pDialogConnectionFailed->set_transient_for(*get_app_window());
-          int response = Glom::Utils::dialog_run_with_help(m_pDialogConnectionFailed, "dialog_error_connection");
-          m_pDialogConnectionFailed->hide();
-
-          //TODO: Combine these into one dialog.
-          if(response != Gtk::RESPONSE_OK)
-            return false; //The user cancelled.
+          Utils::show_ok_dialog(_("Connection Failed"), _("Glom could not connect to the database server. Maybe you entered an incorrect user name or password, or maybe the postgres database server is not running."), *(get_app_window()), Gtk::MESSAGE_ERROR); //TODO: Add help button.
 
           response = Glom::Utils::dialog_run_with_help(m_pDialogConnection, "dialog_connection");
           m_pDialogConnection->hide();
@@ -1761,12 +1734,7 @@ bool Frame_Glom::connection_request_password_and_attempt(std::auto_ptr<Exception
         if(ex.get_failure_type() == ExceptionConnection::FAILURE_NO_SERVER)
         {
           //Warn the user, and let him try again:
-          m_pDialogConnectionFailed->set_transient_for(*get_app_window());
-          int response = Glom::Utils::dialog_run_with_help(m_pDialogConnectionFailed, "dialog_error_connection");
-          m_pDialogConnectionFailed->hide();
-
-          if(response != Gtk::RESPONSE_OK)
-            return false; //The user cancelled.
+          Utils::show_ok_dialog(_("Connection Failed"), _("Glom could not connect to the database server. Maybe you entered an incorrect user name or password, or maybe the postgres database server is not running."), *(get_app_window()), Gtk::MESSAGE_ERROR); //TODO: Add help button.
         }
         else
         {
